# RU

**МЕТКИ** представляют собой простой способ делать заметки с перенаправлением.

Они отлично зарекомендовали себя в ходе разработки игр [Память][memory] и [Маджонг][mahjong].

### Добавление метки

* Добавляем новый файл под любым удобным именем в директорию `метки`
* Генерируем базу файлов всех меток

    ```
    $ ./ген
    ```
* Отправляем изменения в хранилище Git

    ```
    $ git add .
    $ git commit -m "Добавить метку разбора файлов"
    $ git push
    ```

### Формат файла метки

Файл метки имеет следующий формат:

```
ИМЯ
разбор_файлов
ДАТА
2019-08-08
ОПИСАНИЕ
Разбор файлов с метками. АПИ.
Можно несколько строк.
АДРЕС
http://ссылка/на/пример/или/прочерк
```

После разбора файла указанные обязательные ключи будут содержать следующие значения:

| Ключ | Значение |
|---|---|
| ИМЯ | разбор_файлов |
| ДАТА | 2019-08-08 |
| ОПИСАНИЕ | Разбор файлов с метками. АПИ. Можно несколько строк. |
| АДРЕС | http://ссылка/на/пример/или/прочерк |

Примеры файлов меток для игры "Память" можно [посмотреть здесь][memory-metki].

### Перенаправление

Перенаправление осуществляется файлом `метки_1.0.0.html`, который принимает имя метки после знака вопроса `?`.

Пример метки для игры "Память" выглядит следующим образом: http://kornerr.ru/память?и.цвет

### Просмотр существующих меток

Если запрошенного имени метки не существует, отображается список доступных меток с описанием.

Пример списка меток для игры "Память" выглядит следующим образом: http://kornerr.ru/память?лебедьРакЩука

### Создание меток для своего проекта

**МЕТКИ** удобно использовать под конкретный проект. Для этого необходимо:

| № | Шаг | Пример из игры "Память" |
|---|---|---|
| 1 | Создать хранилище с метками | [Хранилище][memory-metki] |
| 2 | Скопировать файл `метки_1.0.0.html` | [метки.html][memory-metki.html] |
| 3 | Задать в нём адрес файла базы меток | [Адрес][memory-metki.html-addr]
| 4 | Создать файл `index.html` для перенаправления на метки с целью сокращения адреса | [index.html][memory-index.html]

# EN

**METKI** (`marks` in Russian) represent a simple way to create bookmarks with redirection.

Marks worked great during the development of [Memory][memory] and [Mahjong][mahjong] games.

### Add a mark

* Add a new file under any name into `метки` directory
* Generate base file for all marks

    ```
    $ ./ген
    ```
* Commit changes to Git repository

    ```
    $ git add .
    $ git commit -m "Add a mark to parse files"
    $ git push
    ```

### Mark file format

Mark file has the following format:

```
ИМЯ
parse_files
ДАТА
2019-08-08
ОПИСАНИЕ
Parsing files with marks. API.
We can use more than one line.
АДРЕС
http://link/to/the/sample/or/a/dash
```

Once the file is parsed, mandatory keys specified above have the following values:

| Key | Key description | Value |
|---|---|---|
| ИМЯ | Name | parse_files |
| ДАТА | Date | 2019-08-08 |
| ОПИСАНИЕ | Description | Parsing files with marks. API. We can use more than one line. |
| АДРЕС | Address | http://link/to/the/sample/or/a/dash |

Have a look at "Memory" game [mark files here][memory-metki].

### Redirection

Redirection is performed by `метки_1.0.0.html` file, which accepts mark's name after question mark `?`.

"Memory" game mark looks like this: http://kornerr.ru/память?и.цвет

### List existing marks

When requested mark name does not exist, a list of all existing marks is presented.

List of "Memory" game marks can be retrieved like this: http://kornerr.ru/память?sputnik.balalaika

### Create marks for your project

Marks are convenient to use per project. To have marks for your project, you need to:

| № | Step | "Memory" game sample |
|---|---|---|
| 1 | Create repository with marks | [Repository][memory-metki] |
| 2 | Copy `метки_1.0.0.html` file (under any name) | [метки.html][memory-metki.html] |
| 3 | Update it to point to URL of your base file with marks | [Address][memory-metki.html-addr]
| 4 | Create `index.html` file that redirects to marks to shorten URL | [index.html][memory-index.html]

[memory]: http://kornerr.ru/память?метки
[mahjong]: http://kornerr.ru/маджонг?метки
[memory-metki]: http://git.opengamestudio.org/kornerr/memory-metki
[memory-metki.html]: http://github.com/kornerr/kornerr.github.io/blob/master/память/метки.html
[memory-metki.html-addr]: http://github.com/kornerr/kornerr.github.io/blob/master/память/метки.html#L297
[memory-index.html]: http://github.com/kornerr/kornerr.github.io/blob/master/память/index.html
